boofun.analysis.cryptographic
=============================

.. automodule:: boofun.analysis.cryptographic


   .. rubric:: Functions

   .. autosummary::

      algebraic_degree
      algebraic_immunity
      algebraic_normal_form
      anf_monomials
      correlation_immunity
      difference_distribution_table
      differential_uniformity
      is_balanced
      is_bent
      linear_approximation_table
      linearity
      nonlinearity
      propagation_criterion
      resiliency
      strict_avalanche_criterion
      walsh_spectrum
      walsh_transform

   .. rubric:: Classes

   .. autosummary::

      CryptographicAnalyzer
      SBoxAnalyzer
